function plotImdataSISC(W,H,D,Rec)

% Plotting function for the SISC algorithm
% 
% Plots the reconstruction of each factor as well as W, H, D and Rec in
% separate figures.
%
% Usage:
%     plotImdataSISC(V,W,H,R);
%     
% Input:
%     V                 M x N data matrix
%     W                 Tau(1) x d x Tau(2) data matrix
%     H                 d x N x Phi data matrix
%     Rec               Reconstructed data matrix


d=size(W,2);
if nargin>3
    mfig('Rec.Spectrogram'); 
    imagesc(Rec/max(Rec(:))); axis image; 
    axis off;
end

    
mfig('(W)'); 
for idx = 1:d
    subplot(1,8,idx)
    if size(W,3)==1
        plot(1:size(W,1),W(:,idx));
    else
        for k=1:size(D,1)
            Q(:,:,k)=W(:,idx,:)*D(k,idx);
        end
        imagesc(squeeze(Q/(max(Q(:))+eps))); 
        axis image;
        axis off;
    end
end


for idx = 1:d
    figure('name',['SparseCode component ' num2str(idx)]);
    if size(H,3)==1
        plot(1:size(H,2),H(idx,:)); 
    else
        imagesc(squeeze(H(idx,:,:))');
        axis image;
        axis off;
    end
    colormap(1-gray)
end
drawnow;

