function plotMusicSISC(W,H,D,sizeV,cmp);

% Plotting function for the SISC algorithm
% 
% Plots the reconstruction of each factor as well as W, H, D and Rec in
% separate figures.
%
% Usage:
%     plotMusicSisc(W,H,D,Rec,cmp);
%     
% Input:
%     V                 M x N data matrix
%     W                 Tau(1) x d x Tau(2) data matrix
%     H                 d x N x Phi data matrix
%     sizeV             size of the original data, i.e. size(V)
%     cmp               component to reconstruct

d=size(W,2);
prair=0.15; % percent air between plots;
vt=(size(H,3)+sizeV(1));
ht=(size(W,3)+sizeV(2));
y_H = size(H,3)/vt*(1-prair);
y_H2 = size(H,2)/ht*(1-prair);
y_W = size(W,3)/ht*(1-prair);
y_W1 = size(W,1)/vt*(1-prair);
y_R1 =sizeV(1)/vt*(1-prair);
y_R2 =sizeV(2)/ht*(1-prair);
air2=prair/(4); % Vertical air space
air1=prair/(4); % Horizontal air space

%h = axes('position', [0 0 1 1]);
%set(h, 'Visible', 'off');

% Plot W
h = axes('position', [air1 2*air2 y_W y_W1]);
imagesc(squeeze(W(:,cmp,:))/(max(max(squeeze(W(:,cmp,:))))+eps));
axis xy;
set(h, 'XTick', []);
set(h, 'yTick', []);
set(h, 'XAxisLocation', 'top');
xlabel('\tau');

% Plot H
h = axes('position', [2*air1+y_W y_R1+3*air2  y_H2 y_H]);
imagesc((squeeze(H(cmp,:,:))'));
colormap(1-gray);
axis xy;
set(h, 'XTick', []);
set(h, 'yTick', []);
ylabel('\phi');

% Plot D
h = axes('position', [1*air1 y_R1+3*air2  y_W y_H]);
bar(D(:,cmp));

% Plot Rec
Rec=ReconstructData(W, H, D,cmp);
if length(sizeV)>2
    Rec = Rec(1:sizeV(1),1:sizeV(2),1:sizeV(3));
else
    Rec = Rec(1:sizeV(1),1:sizeV(2));
end
h = axes('position', [2*air1+y_W 2*air2 y_R2 y_R1]);
if size(Rec,3)==1 | size(Rec,3)==3
    imagesc(Rec/max(Rec(:)));
else
    mRec=squeeze(mean(Rec,3));
    imagesc(mRec/max(mRec(:)));
end
axis xy;
set(h, 'XTick', []);
set(h, 'yTick', []);
